@@ -1,4 +1,6 @@
 require "rbconfig"
+require "tempfile"
+require "stringio"
 
 module Minitest
   ##
@@ -6,7 +8,7 @@ module Minitest
   # printed if the assertion fails.
   #
   # Protocol: Nearly everything here boils up to +assert+, which
-  # expects to be able to increment an instance variable named
+  # expects to be able to increment an instance accessor named
   # +assertions+. This is not provided by Assertions and must be
   # provided by the thing including Assertions. See Minitest::Runnable
   # for an example.
@@ -23,7 +25,7 @@ module Minitest
     # figure out what diff to use.
 
     def self.diff
-      @diff = if (RbConfig::CONFIG['host_os'] =~ /mswin|mingw/ &&
+      @diff = if (RbConfig::CONFIG["host_os"] =~ /mswin|mingw/ &&
                   system("diff.exe", __FILE__, __FILE__)) then
                 "diff.exe -u"
               elsif Minitest::Test.maglev? then
@@ -53,19 +55,17 @@ module Minitest
     # comparison between the two.
 
     def diff exp, act
-      require "tempfile"
-
       expect = mu_pp_for_diff exp
       butwas = mu_pp_for_diff act
       result = nil
 
       need_to_diff =
-        Minitest::Assertions.diff &&
         (expect.include?("\n")    ||
          butwas.include?("\n")    ||
          expect.size > 30         ||
          butwas.size > 30         ||
-         expect == butwas)
+         expect == butwas)        &&
+        Minitest::Assertions.diff
 
       return "Expected: #{mu_pp exp}\n  Actual: #{mu_pp act}" unless
         need_to_diff
@@ -115,16 +115,16 @@ module Minitest
     # uses mu_pp to do the first pass and then cleans it up.
 
     def mu_pp_for_diff obj
-      mu_pp(obj).gsub(/\\n/, "\n").gsub(/:0x[a-fA-F0-9]{4,}/m, ':0xXXXXXX')
+      mu_pp(obj).gsub(/\\n/, "\n").gsub(/:0x[a-fA-F0-9]{4,}/m, ":0xXXXXXX")
     end
 
     ##
     # Fails unless +test+ is truthy.
 
     def assert test, msg = nil
-      msg ||= "Failed assertion, no message given."
       self.assertions += 1
       unless test then
+        msg ||= "Failed assertion, no message given."
         msg = msg.call if Proc === msg
         raise Minitest::Assertion, msg
       end
@@ -144,6 +144,8 @@ module Minitest
       assert obj.empty?, msg
     end
 
+    E = "" # :nodoc:
+
     ##
     # Fails unless <tt>exp == act</tt> printing the difference between
     # the two, if possible.
@@ -157,7 +159,7 @@ module Minitest
     # See also: Minitest::Assertions.diff
 
     def assert_equal exp, act, msg = nil
-      msg = message(msg, "") { diff exp, act }
+      msg = message(msg, E) { diff exp, act }
       assert exp == act, msg
     end
 
@@ -285,29 +287,29 @@ module Minitest
     ##
     # Fails unless the block raises one of +exp+. Returns the
     # exception matched so you can check the message, attributes, etc.
+    #
+    # +exp+ takes an optional message on the end to help explain
+    # failures and defaults to StandardError if no exception class is
+    # passed.
 
     def assert_raises *exp
       msg = "#{exp.pop}.\n" if String === exp.last
+      exp << StandardError if exp.empty?
 
       begin
         yield
-      rescue Minitest::Skip => e
-        return e if exp.include? Minitest::Skip
-        raise e
+      rescue *exp => e
+        pass # count assertion
+        return e
+      rescue Minitest::Skip, Minitest::Assertion
+        # don't count assertion
+        raise
+      rescue SignalException, SystemExit
+        raise
       rescue Exception => e
-        expected = exp.any? { |ex|
-          if ex.instance_of? Module then
-            e.kind_of? ex
-          else
-            e.instance_of? ex
-          end
-        }
-
-        assert expected, proc {
+        flunk proc {
           exception_details(e, "#{msg}#{mu_pp(exp)} exception expected, not")
         }
-
-        return e
       end
 
       exp = exp.first if exp.size == 1
@@ -399,19 +401,17 @@ module Minitest
     def capture_io
       _synchronize do
         begin
-      require 'stringio'
+          captured_stdout, captured_stderr = StringIO.new, StringIO.new
 
-      captured_stdout, captured_stderr = StringIO.new, StringIO.new
+          orig_stdout, orig_stderr = $stdout, $stderr
+          $stdout, $stderr         = captured_stdout, captured_stderr
 
-      orig_stdout, orig_stderr = $stdout, $stderr
-      $stdout, $stderr         = captured_stdout, captured_stderr
+          yield
 
-      yield
-
-      return captured_stdout.string, captured_stderr.string
-    ensure
-      $stdout = orig_stdout
-      $stderr = orig_stderr
+          return captured_stdout.string, captured_stderr.string
+        ensure
+          $stdout = orig_stdout
+          $stderr = orig_stderr
         end
       end
     end
@@ -434,25 +434,25 @@ module Minitest
     def capture_subprocess_io
       _synchronize do
         begin
-      require 'tempfile'
+          require "tempfile"
 
-      captured_stdout, captured_stderr = Tempfile.new("out"), Tempfile.new("err")
+          captured_stdout, captured_stderr = Tempfile.new("out"), Tempfile.new("err")
 
-      orig_stdout, orig_stderr = $stdout.dup, $stderr.dup
-      $stdout.reopen captured_stdout
-      $stderr.reopen captured_stderr
+          orig_stdout, orig_stderr = $stdout.dup, $stderr.dup
+          $stdout.reopen captured_stdout
+          $stderr.reopen captured_stderr
 
-      yield
+          yield
 
-      $stdout.rewind
-      $stderr.rewind
+          $stdout.rewind
+          $stderr.rewind
 
-      return captured_stdout.read, captured_stderr.read
-    ensure
-      captured_stdout.unlink
-      captured_stderr.unlink
-      $stdout.reopen orig_stdout
-      $stderr.reopen orig_stderr
+          return captured_stdout.read, captured_stderr.read
+        ensure
+          captured_stdout.unlink
+          captured_stderr.unlink
+          $stdout.reopen orig_stdout
+          $stderr.reopen orig_stderr
         end
       end
     end
@@ -466,7 +466,7 @@ module Minitest
        "Class: <#{e.class}>",
        "Message: <#{e.message.inspect}>",
        "---Backtrace---",
-       "#{Minitest::filter_backtrace(e.backtrace).join("\n")}",
+       "#{Minitest.filter_backtrace(e.backtrace).join("\n")}",
        "---------------",
       ].join "\n"
     end
@@ -482,18 +482,18 @@ module Minitest
     ##
     # Returns a proc that will output +msg+ along with the default message.
 
-    def message msg = nil, ending = ".", &default
+    def message msg = nil, ending = nil, &default
       proc {
         msg = msg.call.chomp(".") if Proc === msg
         custom_message = "#{msg}.\n" unless msg.nil? or msg.to_s.empty?
-        "#{custom_message}#{default.call}#{ending}"
+        "#{custom_message}#{default.call}#{ending || "."}"
       }
     end
 
     ##
     # used for counting assertions
 
-    def pass msg = nil
+    def pass _msg = nil
       assert true
     end
 
@@ -502,7 +502,7 @@ module Minitest
 
     def refute test, msg = nil
       msg ||= "Failed refutation, no message given"
-      not assert(! test, msg)
+      not assert !test, msg
     end
 
     ##
@@ -580,7 +580,7 @@ module Minitest
     # Fails if +matcher+ <tt>=~</tt> +obj+.
 
     def refute_match matcher, obj, msg = nil
-      msg = message(msg) {"Expected #{mu_pp matcher} to not match #{mu_pp obj}"}
+      msg = message(msg) { "Expected #{mu_pp matcher} to not match #{mu_pp obj}" }
       assert_respond_to matcher, :"=~"
       matcher = Regexp.new Regexp.escape matcher if String === matcher
       refute matcher =~ obj, msg
@@ -602,7 +602,7 @@ module Minitest
 
     def refute_operator o1, op, o2 = UNDEFINED, msg = nil
       return refute_predicate o1, op, msg if UNDEFINED == o2
-      msg = message(msg) { "Expected #{mu_pp(o1)} to not be #{op} #{mu_pp(o2)}"}
+      msg = message(msg) { "Expected #{mu_pp(o1)} to not be #{op} #{mu_pp(o2)}" }
       refute o1.__send__(op, o2), msg
     end
 
